#!/usr/bin/env node
const fs = require('fs');
const ncp = require('ncp');
const colors = require('colors');
const {exec} = require('child_process');

// Delete the 0 and 1 argument (node and index.js)
const args = process.argv.splice(process.execArgv.length + 2);
let path_to_folder = args[0];

// Check for help flag & error handling
if (args.includes('--help') || args.length == 0) return console.log(args.length == 0 ? '\nError'.bold.red : '', '\nStructure of command:'.bold.brightGreen, '\ncreate-app-react-express [path_to_folder] --options'.bold.cyan);

// Creating App template files and folders
(async() => {
	try {
		// Checking if path_to_folder exists and if it doesnt creating a new one
		if (!fs.existsSync(path_to_folder)) fs.mkdirSync(path_to_folder);
		else if (fs.readdirSync(path_to_folder).length != 0) throw `"${path_to_folder}" is not empty\nPlase make sure there are no items in the folder`;

		// Coppying over lib folder into the specified by the user folder path
		ncp(__dirname+'/lib', path_to_folder, (err) => {
			if (err) throw 'There was a problem copying over the files';
			else console.log('\nCreated Files and folders...'.cyan.bold, '\nExecuting npm install...'.cyan.bold);
		});

		exec(`(cd ${path_to_folder} && npm install)`, (err, stdout, stderr) => {
			if (err) throw 'npm install failed to get the packages';

			// Logging successful app creation
			console.log('\nReact & Express App created in: "'.cyan.bold + `${path_to_folder}`.bold.yellow + '"'.cyan.bold, '\nIn the specified directory please run:\n"npm run build" and \n"npm run start" to get started'.cyan.bold, '\n\nHappy Hacking!'.red.bold);
		});
	} catch (err) {
		return console.log('\nError!'.cyan.underline.bold, `\n${err}`.brightMagenta.italic);
	}
})();